@@ -18,11 +18,9 @@ if [ -e etc/rc.d/rc.messagebus ]; then
   mv etc/rc.d/rc.messagebus.new.incoming etc/rc.d/rc.messagebus.new
 fi
 
-config etc/dbus-1/session.conf.new
-config etc/dbus-1/system.conf.new
 config etc/rc.d/rc.messagebus.new
 
 ( cd usr/lib ; rm -rf libdbus-1.so )
-( cd usr/lib ; ln -sf libdbus-1.so.3.4.0 libdbus-1.so )
+( cd usr/lib ; ln -sf libdbus-1.so.3.5.3 libdbus-1.so )
 ( cd usr/lib ; rm -rf libdbus-1.so.3 )
-( cd usr/lib ; ln -sf libdbus-1.so.3.4.0 libdbus-1.so.3 )
+( cd usr/lib ; ln -sf libdbus-1.so.3.5.3 libdbus-1.so.3 )
